<?php

/**
 * Created by PhpStorm.
 * User: sebastien
 * Date: 2018-12-13
 * Time: 15:31
 */

namespace WeLoveCustomers\Connector\Endpoint;


use Magento\SalesRule\Model\Rule;
use Magento\Store\Model\StoreManager;
use WeLoveCustomers\Connector\Block\Adminhtml\System\Config\Versionnumber;
use WeLoveCustomers\Connector\DTO\OfferApiResponse;
use WeLoveCustomers\Connector\Model\Offer;
use Magento\Customer\Model\ResourceModel\Group\Collection;

class OfferEndpoint extends BaseEndpoint
{

    /**
     * @var StoreManager
     */
    private $manager;

    /**
     * @var Collection
     */
    private $groups;

    /**
     * OfferEndpoint constructor.
     * @param Versionnumber $client
     */
    public function __construct(StoreManager $storeManager, Collection $groups)
    {
        $this->manager = $storeManager;
        $this->groups = $groups;
    }

    /**
     * @param string $couponCode
     * @return OfferApiResponse|null
     */
    public function findOfferByCode($couponCode)
    {

        $jsonResponse = $this->doAuthRequest('checkOfferCode', array(
            'inputCode' => $couponCode
        ));
        // var_dump(json_decode($jsonResponse, 1));
        // exit();
        if ($jsonResponse) {
			$data = json_decode($jsonResponse, 1);
			// if(isset($data["id"])){
				$offer = new OfferApiResponse(json_decode($jsonResponse, 1));

				return $offer->res ? $offer : null;
			// }
        }

        return null;
    }

    /**
     * @param string $code
     * @param Offer $offer
     * @return array
     */
    public function convertOfferToPostData($code, Offer $offer)
    {

        $websitesId = array_map(function ($website) {
            return $website->getId();
        }, $this->manager->getWebsites());

        $groupsId = array_map(function ($group) {
            return $group['value'];
        }, $this->groups->toOptionArray());

        $rule = array(
            'rule_id' => null,
            'name' => $offer->title,
            'description' => strip_tags($offer->description),
            'from_date' => $offer->dateFrom,
            'to_date' => $offer->dateTo,
            'uses_per_customer' => 1,
            'is_active' => '1',
            'stop_rules_processing' => '0',
            'is_advanced' => '1',
            'sort_order' => '0',
            'simple_action' => $offer->offerValueType == Offer::TYPE_PERCENT ? Rule::BY_PERCENT_ACTION : Rule::CART_FIXED_ACTION,
            'discount_amount' => $offer->offerValueType == Offer::TYPE_FREE_SHIPPING ? 0 : $offer->offerValue,
            'discount_qty' => 0,
            'discount_step' => '0',
            'apply_to_shipping' => '0',
            'times_used' => '0',
            'is_rss' => '0',
            'coupon_type' => Rule::COUPON_TYPE_SPECIFIC,
            'use_auto_generation' => '0',
            'uses_per_coupon' => 1,
            'simple_free_shipping' => $offer->offerValueType == Offer::TYPE_FREE_SHIPPING ? 1 : 0,
            'code' => $code,
            'website_ids' => $websitesId,
            'customer_group_ids' => $groupsId,
            'coupon_code' => $code,
            'store_labels' =>
            array(
                0 => '',
            )
        );




        /*
        if ($offer->minimumAmountToBuy){
            $conditions = array(
                "1" => array(
                    "type" => "salesrule/rule_condition_combine",
                    "aggregator" => "all",
                    "value" => "1",
                    "new_child" => null
                ),
                "1--1" => array(
                    "type" => "salesrule/rule_condition_address",
                    "attribute" => "base_subtotal",
                    "operator" => ">=",
                    "value" => $offer->minimumAmountToBuy
                ),
            );
        }
        $rule['conditions'] = $conditions;
        */


        if ($offer->excludeSku) {
            $allExcludeSku = explode(',', $offer->excludeSku);
            $conditions = array(
                'type' => \Magento\SalesRule\Model\Rule\Condition\Product\Combine::class,
                'attribute' => null,
                'operator' => null,
                'value' => '1',
                'is_value_processed' => null,
                'aggregator' => 'all',
                'conditions' => [],
            );
            foreach ($allExcludeSku as $excludeSku) {
                $conditions['conditions'][] =
                    [
                        'type' => \Magento\SalesRule\Model\Rule\Condition\Product::class,
                        'attribute' => 'sku',
                        'operator' => '!=',
                        'value' => $excludeSku,
                        'is_value_processed' => false,
                        'attribute_scope' => ''
                    ];
            }

            $rule['actions_serialized'] = json_encode($conditions);
        }

        if ($offer->minimumAmountToBuy) {
            $conditions = array(
                'type' => \Magento\SalesRule\Model\Rule\Condition\Combine::class,
                'attribute' => null,
                'operator' => null,
                'value' => '1',
                'is_value_processed' => null,
                'aggregator' => 'all',
                'conditions' => [
                    [
                        'type' => \Magento\SalesRule\Model\Rule\Condition\Address::class,
                        'attribute' => 'base_subtotal',
                        'operator' => '>=',
                        'value' => $offer->minimumAmountToBuy,
                        'is_value_processed' => false,
                    ],
                ],
            );

            $rule['conditions_serialized'] = json_encode($conditions);
        }

        return $rule;
    }
}
